@@ -10,9 +10,9 @@ class EndpointMeta(BaseModel):
 
     @property
     def port_int(self) -> int | None:
-        if isinstance(self.port, str):
+        if self.port and isinstance(self.port, str):
             return int(self.port)
-        return self.port
+        return self.port or None
 
 
 class AuthMeta(BaseModel):
@@ -38,8 +38,10 @@ class DBConnectionMeta(EndpointMeta, AuthMeta, URIConnectionMeta):
         if self.host:
             meta = f"{self.host}:{self.port}"
             if self.username:
-                return f"{base}://{self.username}:{self.password}@{meta}/{self.database if with_db else ''}"
-            return f"{base}://{meta}/{self.database if with_db else ''}"
+                return f"{base}://{self.username}:{self.password}@{meta}/{self.database if with_db and self.database else ''}"
+            return (
+                f"{base}://{meta}/{self.database if with_db and self.database else ''}"
+            )
         return ""
 
     @model_validator(mode="after")
@@ -67,12 +69,15 @@ class DBConnectionMeta(EndpointMeta, AuthMeta, URIConnectionMeta):
             metadata, others = (
                 re.split(r"\/\?|\/", uri) if re.search(r"\/\?|\/", uri) else [uri, None]
             )
-            if others and "&" in others:
-                for other in others.split("&"):
-                    if "=" in other and re.search(r"authSource", other):
-                        self.database = other.split("=")[-1]
-                    elif "=" not in other:
-                        self.database = other
+            if others and not self.database:
+                if "&" in others:
+                    for other in others.split("&"):
+                        if "=" in other and re.search(r"authSource", other):
+                            self.database = other.split("=")[-1]
+                        elif "=" not in other:
+                            self.database = other
+                else:
+                    self.database = others
             if "@" in metadata:
                 self.username, self.password, self.host, self.port = re.split(
                     r"\@|\:", metadata
@@ -101,8 +106,10 @@ class ClusterConnectionMeta(AuthMeta, URIConnectionMeta):
         if self.cluster_uri:
             meta = ",".join([f"{c.host}:{c.port}" for c in self.cluster_uri])
             if self.username:
-                return f"{base}://{self.username}:{self.password}@{meta}/{self.database if with_db else ''}"
-            return f"{base}://{meta}/{self.database if with_db else ''}"
+                return f"{base}://{self.username}:{self.password}@{meta}/{self.database if with_db and self.database else ''}"
+            return (
+                f"{base}://{meta}/{self.database if with_db and self.database else ''}"
+            )
         return ""
 
     @model_validator(mode="after")
@@ -124,12 +131,15 @@ class ClusterConnectionMeta(AuthMeta, URIConnectionMeta):
                 re.split(r"\/\?|\/", uri) if re.search(r"\/\?|\/", uri) else [uri, None]
             )
             cluster_uri = []
-            if others and "&" in others:
-                for other in others.split("&"):
-                    if "=" in other and re.search(r"authSource", other):
-                        self.database = other.split("=")[-1]
-                    elif "=" not in other:
-                        self.database = other
+            if others and not self.database:
+                if "&" in others:
+                    for other in others.split("&"):
+                        if "=" in other and re.search(r"authSource", other):
+                            self.database = other.split("=")[-1]
+                        elif "=" not in other:
+                            self.database = other
+                else:
+                    self.database = others
             if "@" in clean_meta:
                 auth_meta, clean_meta = re.split(r"\@", clean_meta)
                 self.username, self.password = re.split(r"\:", auth_meta)
