@@ -66,5 +66,5 @@ class MongoConnector:
 
         This method is a no-op if the connection is already closed.
         """
-        if self._client:
+        if hasattr(self, "_client") and self._client:
             self._client.close()
